var window = window || {};

/**
 * Setup functionality for the DMG Media privacy hub
 */
window.dmgPrivacyHub = {

    /**
     * Attach listeners to various elements
     */
    attachListeners: function () {

        // Show the privacy modal
        document.getElementById("dmg-privacy__submit").addEventListener("click", function (e) {
            e.preventDefault();
            document.getElementById("dmg-privacy__popup").classList.remove("dmg-privacy__popup--hidden");
        });

        // Hide the privacy modal
        document.getElementById("dmg-privacy__popup__close").addEventListener("click", function (e) {
            e.preventDefault();
            document.getElementById("dmg-privacy__popup").classList.add("dmg-privacy__popup--hidden");
        });

        // Toggle the accordion panels
        const panels = document.getElementsByClassName("dmg-privacy__accordion__section");
        for (let i = 0; i < panels.length; i++) {
            panels.item(i).addEventListener("click", function (e) {
                e.preventDefault();
                this.classList.toggle("active");

                /* Toggle between hiding and showing the active panel */
                let panel = this.nextElementSibling;
                if (panel.style.maxHeight) {
                    panel.style.maxHeight = null;
                } else {
                    panel.style.maxHeight = panel.scrollHeight + "px";
                }
            });
        }
    },

    /**
     * 
     */
    getDSRform: function () {
        const xhrBrands = new XMLHttpRequest();
        xhrBrands.open("GET", "https://dmgmedia.co.uk/wp-json/wp/v2/privacy_hub_brand/", true);
        xhrBrands.responseType = "json";
        xhrBrands.send();

        xhrBrands.onreadystatechange = function () {
            if (xhrBrands.readyState === 4) {
                xhrBrands.response.forEach(function (brand) {
                    let privacyUrl = brand.acf.privacy_page_url,
                        dsrUrl = brand.acf.data_subject_request_url,
                        privacyDomain = (new URL(privacyUrl)),
                        browserUrl = (new URL(window.location.href));

                    browserUrl = browserUrl.hostname.replace("www.", "").split(".")[0];
                    privacyDomain = privacyDomain.hostname.replace("www.", "").split(".")[0];

                    if ((browserUrl === privacyDomain) && (dsrUrl != "")) {
                        document.querySelectorAll(".dsr-form").forEach(function (el) {
                            el.href = dsrUrl;
                        });
                    }
                });
            }
        };
    }
}

window.addEventListener("DOMContentLoaded", () => {
    window.dmgPrivacyHub.attachListeners();
    window.dmgPrivacyHub.getDSRform();
});
